abacusai.custom_domain — AbacusAI documentation

# abacusai.custom_domain

## Classes

`CustomDomain` | Result of adding a custom domain to a hosted app

## Module Contents

class abacusai.custom_domain.CustomDomain(client, status=None, message=None, expectedNameservers=None, currentNameservers=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Result of adding a custom domain to a hosted app

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - status (bool) – Whether the custom domain was added successfully

    - message (str) – The message from the custom domain

    - expectedNameservers (list) – The expected nameservers for the custom domain

    - currentNameservers (list) – The current nameservers for the custom domain

  status = None
  message = None
  expected_nameservers = None
  current_nameservers = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict